==> aliyun-java-sdk-vod-2.15.2-sources.jar: com/aliyuncs/vod/model/v20170321/DeleteWatermarkRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod.model.v20170321;

import com.aliyuncs.RpcAcsRequest;

/**
 * @author auto create
 * @version 
 */
public class DeleteWatermarkRequest extends RpcAcsRequest<DeleteWatermarkResponse> {
	
	public DeleteWatermarkRequest() {
		super("vod", "2017-03-21", "DeleteWatermark", "vod");
	}

	private String watermarkId;

	private Long resourceOwnerId;

	private String resourceOwnerAccount;

	private Long ownerId;

	public String getWatermarkId() {
		return this.watermarkId;
	}

	public void setWatermarkId(String watermarkId) {
		this.watermarkId = watermarkId;
		if(watermarkId != null){
			putQueryParameter("WatermarkId", watermarkId);
		}
	}

	public Long getResourceOwnerId() {
		return this.resourceOwnerId;
	}

	public void setResourceOwnerId(Long resourceOwnerId) {
		this.resourceOwnerId = resourceOwnerId;
		if(resourceOwnerId != null){
			putQueryParameter("ResourceOwnerId", resourceOwnerId.toString());
		}
	}

	public String getResourceOwnerAccount() {
		return this.resourceOwnerAccount;
	}

	public void setResourceOwnerAccount(String resourceOwnerAccount) {
		this.resourceOwnerAccount = resourceOwnerAccount;
		if(resourceOwnerAccount != null){
			putQueryParameter("ResourceOwnerAccount", resourceOwnerAccount);
		}
	}

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		if(ownerId != null){
			putQueryParameter("OwnerId", ownerId.toString());
		}
	}

	@Override
	public Class<DeleteWatermarkResponse> getResponseClass() {
		return DeleteWatermarkResponse.class;
	}

}

==> aliyun-java-sdk-vod-2.15.11-sources.jar: com/aliyuncs/vod/model/v20170321/DeleteWatermarkRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod.model.v20170321;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.vod.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class DeleteWatermarkRequest extends RpcAcsRequest<DeleteWatermarkResponse> {
	   

	private Long resourceOwnerId;

	private String resourceOwnerAccount;

	private Long ownerId;

	private String watermarkId;
	public DeleteWatermarkRequest() {
		super("vod", "2017-03-21", "DeleteWatermark", "vod");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public Long getResourceOwnerId() {
		return this.resourceOwnerId;
	}

	public void setResourceOwnerId(Long resourceOwnerId) {
		this.resourceOwnerId = resourceOwnerId;
		if(resourceOwnerId != null){
			putQueryParameter("ResourceOwnerId", resourceOwnerId.toString());
		}
	}

	public String getResourceOwnerAccount() {
		return this.resourceOwnerAccount;
	}

	public void setResourceOwnerAccount(String resourceOwnerAccount) {
		this.resourceOwnerAccount = resourceOwnerAccount;
		if(resourceOwnerAccount != null){
			putQueryParameter("ResourceOwnerAccount", resourceOwnerAccount);
		}
	}

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		if(ownerId != null){
			putQueryParameter("OwnerId", ownerId.toString());
		}
	}

	public String getWatermarkId() {
		return this.watermarkId;
	}

	public void setWatermarkId(String watermarkId) {
		this.watermarkId = watermarkId;
		if(watermarkId != null){
			putQueryParameter("WatermarkId", watermarkId);
		}
	}

	@Override
	public Class<DeleteWatermarkResponse> getResponseClass() {
		return DeleteWatermarkResponse.class;
	}

}
